@@ -1,16 +1,15 @@
 
 /*
  *  autogen.h
- *  $Id: autogen.h,v 4.33 2008/01/23 00:36:00 bkorb Exp $
+ *  $Id: autogen.h,v 4.35 2009/01/01 16:51:42 bkorb Exp $
  *
- *  Time-stamp:        "2007-11-10 15:04:13 bkorb"
- *  Last Committed:    $Date: 2008/01/23 00:36:00 $
+ *  Time-stamp:        "2008-12-31 13:53:26 bkorb"
+ *  Last Committed:    $Date: 2009/01/01 16:51:42 $
  *
  *  Global header file for AutoGen
  *
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2008 by Bruce Korb - all rights reserved
- *  AutoGen copyright (c) 1992-2008 by Bruce Korb - all rights reserved
+ *  AutoGen copyright (c) 1992-2009 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -300,6 +299,9 @@ typedef struct {
     char*   entries[1];
 } tList;
 
+#define _MkStr(_s) #_s
+#define MK_STR(_s) _MkStr(_s)
+
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
  *  GLOBAL VARIABLES
@@ -326,7 +328,7 @@ MODE FILE*       pfTrace          VALUE( NULL );
 MODE char*       pzTmpStderr      VALUE( NULL );
 
 MODE tCC*        serverArgs[2]    VALUE( { NULL } );
-MODE tCC*        pzShellProgram   VALUE( NULL );
+MODE tCC*        pzShellProgram   VALUE( MK_STR(CONFIG_SHELL) );
 
 /*
  *  AutoGen definiton and template context
