@@ -1,9 +1,9 @@
 /*
  *  defDirect.c
- *  $Id: defDirect.c,v 4.21 2008/01/23 00:36:00 bkorb Exp $
+ *  $Id: defDirect.c,v 4.23 2009/01/01 16:51:42 bkorb Exp $
  *
- *  Time-stamp:        "2007-11-17 09:46:24 bkorb"
- *  Last Committed:    $Date: 2008/01/23 00:36:00 $
+ *  Time-stamp:        "2008-09-23 09:06:37 bkorb"
+ *  Last Committed:    $Date: 2009/01/01 16:51:42 $
  *
  *  This module processes definition file directives.
  *
@@ -15,8 +15,7 @@
  *    trail='\+\+\+ End of Directives'
  *
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2008 by Bruce Korb - all rights reserved
- *  AutoGen copyright (c) 1992-2008 by Bruce Korb - all rights reserved
+ *  AutoGen copyright (c) 1992-2009 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -228,7 +227,7 @@ skipToEndif( char* pzStart )
             if (pz != NULL)
                  pzRet = pz+1;
             else pzRet = pzScan + strlen( pzScan );
-            goto leave;
+            goto leave_func;
         }
 
         case DIR_IFDEF:
@@ -247,7 +246,7 @@ skipToEndif( char* pzStart )
         }  /* switch (findDirective( pzScan )) */
     }
 
- leave:
+ leave_func:
     while (pzStart < pzRet) {
         if (*(pzStart++) == '\n')
             pCurCtx->lineNo++;
@@ -353,7 +352,7 @@ skipToElseEnd( char* pzStart )
             if (pz != NULL)
                  pzRet = pz+1;
             else pzRet = pzScan + strlen( pzScan );
-            goto leave;
+            goto leave_func;
         }
 
         case DIR_IFDEF:
@@ -374,7 +373,7 @@ skipToElseEnd( char* pzStart )
         }  /* switch (findDirective( pzScan )) */
     }
 
- leave:
+ leave_func:
     while (pzStart < pzRet) {
         if (*(pzStart++) == '\n')
             pCurCtx->lineNo++;
