@@ -1,7 +1,7 @@
 
 /*
- *  usage.c  $Id: usage.c,v 4.28 2008/11/02 18:51:27 bkorb Exp $
- * Time-stamp:      "2008-11-01 20:09:17 bkorb"
+ *  usage.c  $Id: usage.c,v 4.30 2009/01/17 22:08:07 bkorb Exp $
+ * Time-stamp:      "2009-01-17 13:18:23 bkorb"
  *
  *  This module implements the default usage procedure for
  *  Automated Options.  It may be overridden, of course.
@@ -15,8 +15,7 @@
 /*
  *  This file is part of AutoOpts, a companion to AutoGen.
  *  AutoOpts is free software.
- *  AutoOpts is copyright (c) 1992-2008 by Bruce Korb - all rights reserved
- *  AutoOpts is copyright (c) 1992-2008 by Bruce Korb - all rights reserved
+ *  AutoOpts is copyright (c) 1992-2009 by Bruce Korb - all rights reserved
  *
  *  AutoOpts is available under any one of two licenses.  The license
  *  in use must be one of these two and the choice is under the control
@@ -550,7 +549,7 @@ printOptionUsage(
     int        docCt  = 0;
 
     do  {
-        if ((pOD->fOptState & OPTST_OMITTED) != 0)
+        if ((pOD->fOptState & OPTST_NO_USAGE_MASK) != 0)
             continue;
 
         if ((pOD->fOptState & OPTST_DOCUMENT) != 0) {
