@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for getdefs
- * Generated Wed Dec 31 19:07:30 PST 2008
+ * Generated Sat May 16 08:16:06 PDT 2009
  */
 #ifndef GETDEFS_PROTO_H_GUARD
 #define GETDEFS_PROTO_H_GUARD 1
@@ -21,6 +21,12 @@ emitDefinition( char* pzDef, char* pzOut );
 /*
  *  Extracted from gdinit.c
  */
+LOCAL void
+die(char const * fmt, ...);
+
+LOCAL void
+fserr_die(char const * fmt, ...);
+
 LOCAL void
 processEmbeddedOptions( char* pzText );
 
